# -*- coding: utf-8 -*-
"""
mpltex
======

**mpltex** is a python package for producing publication quality images using matplotlib.

"""

__author__ = "Yi-Xin Liu <liuyxpp@gmail.com>"
__license__ = "BSD License"

from ._version import __version__

from .general import *
from .colors import *
from .styles import *
from .layout import *
from .acs import *
from .rsc import *
from .aps import *
from .presentation import *
from .web import *
